@@ -1,3 +1,11 @@
+
+release_questions <- function() {
+  c(
+    "Have you updated the docs? devtools::document()",
+    "Have you updated the website? pkgdown::build_site()"
+  )
+}
+
 #' @section Installation:
 #' Install the R package from \href{https://cran.r-project.org/package=rchallenge}{CRAN} repositories
 #' 
@@ -49,12 +57,12 @@
 #'  
 #'    \code{\link{new_team}("team_foo", "team_bar")}
 #' 
-#'  \item Render the html page:
+#'  \item Render the HTML page:
 #'    \code{\link{publish}()}
 #'    Use the \code{output_dir} argument to change the output directory.
 #'    Make sure the output HTML file is rendered, e.g. using \href{https://pages.github.com/}{GitHub Pages}.
 #' 
-#'  \item Give the URL to your \code{challenge.html} file to the participants.
+#'  \item Give the URL to your HTML file to the participants.
 #'  
 #'  \item Refresh the webpage by repeating step 2 on a regular basis. See below for automating this step.
 #' }
@@ -83,6 +91,10 @@
 #' This will render a HTML webpage every hour.
 #' Use the \code{output_dir} argument to change the output directory.
 #' 
+#' If your challenge is hosted on a Github repository you can automate the push:
+#' 
+#' \code{0 * * * * cd ~/Dropbox/mychallenge && Rscript -e 'rchallenge::publish()' && git commit -m "update html" index.html && git push}
+#' 
 #' You might have to add the path to Rscript and pandoc at the beginning of your crontab:
 #'  
 #' \code{PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin}
@@ -108,9 +120,22 @@
 #' 
 #' @section Examples:
 #' \itemize{ 
-#'  \item \href{https://adrtod.github.io/challenge_mimse2014.html}{My own challenge} (in french) given to Master students at the University of Bordeaux.
+#'  \item \href{https://adrtod.github.io/challenge-mimse2014/}{My own challenge} (in french) given to Master students at the University of Bordeaux.
 #'  \item \href{https://dl.dropboxusercontent.com/u/50849929/challenge_fr.html}{A classification and variable selection problem} (in french) given by Robin Genuer (Bordeaux).
 #' }
 #' 
 #' Please \href{https://adrtod.github.io}{contact me} to add yours.
 "_PACKAGE"
+
+
+#' Defunct functions in package \sQuote{rchallenge}
+#' 
+#' These functions are defunct and no longer available.
+#' @name rchallenge-defunct
+#' @aliases glyphicon 
+#' @export 
+#' @param ... parameters 
+#' @details Defunct functions are: \code{glyphicon}
+glyphicon <- function(...) {
+  .Defunct("icon", "rchallenge")
+}
